@@ -4,6 +4,9 @@
 //    also supported is to build first, with java17, then switch the java version, and run the test with java8:
 // gradle clean build -x javaDoc -x test
 // gradle test
+
+import java.util.jar.JarFile
+
 val javacRelease = (project.findProperty("javacRelease") ?: "8") as String
 
 plugins {
@@ -18,9 +21,6 @@ description = "PlantUML"
 java {
 	withSourcesJar()
 	withJavadocJar()
-	registerFeature("pdf") {
-		usingSourceSet(sourceSets["main"])
-	}
 }
 
 dependencies {
@@ -37,24 +37,17 @@ repositories {
 }
 
 sourceSets {
-	main {
-		java {
-			srcDirs("build/generated/sjpp")
-		}
-        resources {
-			srcDirs("../src/main/resources")
-        }
-	}
-}
-
-tasks.processResources {
-    from("../src/main/java") {
-        include("**/graphviz.dat", "**/*.svg", "**/*.png", "**/*.txt")
+  main {
+    java {
+      srcDirs("build/generated/sjpp")
     }
+    resources {
+      srcDir(rootProject.layout.projectDirectory.dir("src/main/resources"))
+    }
+  }
 }
 
 
-
 tasks.compileJava {
 	if (JavaVersion.current().isJava8) {
 		java.targetCompatibility = JavaVersion.VERSION_1_8
@@ -68,13 +61,40 @@ tasks.withType<Jar>().configureEach {
 		attributes["Main-Class"] = "net.sourceforge.plantuml.Run"
 		attributes["Implementation-Version"] = archiveVersion
 		attributes["Build-Jdk-Spec"] = System.getProperty("java.specification.version")
-		from("../manifest.txt")
+		from(rootProject.layout.projectDirectory.file("manifest.txt"))
 	}
 
 	// source sets for java and resources are on "src", only put once into the jar
 	duplicatesStrategy = DuplicatesStrategy.EXCLUDE
 }
 
+val checkJarEntries by tasks.registering {
+    dependsOn(tasks.named("jar"))
+    doLast {
+        val jarFile = tasks.named<Jar>("jar").get().archiveFile.get().asFile
+        JarFile(jarFile).use { jar ->
+            val required = listOf(
+                "net/sourceforge/plantuml/Run.class",
+                "sprites/archimate/access.png",
+                "skin/plantuml.skin"
+            )
+            val missing = required.filter { jar.getEntry(it) == null }
+            if (missing.isNotEmpty()) {
+                throw GradleException("Missing entries in JAR: $missing")
+            }
+        }
+        println("All required entries found in ${jarFile.name}")
+    }
+}
+
+tasks.named<Jar>("jar") {
+    finalizedBy(checkJarEntries)
+}
+
+tasks.named("check") {
+    dependsOn(checkJarEntries)
+}
+
 tasks.withType<JavaCompile>().configureEach {
 	options.encoding = "UTF-8"
 }
@@ -159,16 +179,18 @@ publishing {
 		}
 	}
 	repositories {
-		maven {
-			name = "OSSRH"
-			val releasesRepoUrl = "https://oss.sonatype.org/service/local/staging/deploy/maven2/"
-			val snapshotsRepoUrl = "https://oss.sonatype.org/content/repositories/snapshots/"
-			url = uri(if (version.toString().endsWith("SNAPSHOT")) snapshotsRepoUrl else releasesRepoUrl)
-			credentials {
-				username = System.getenv("OSSRH_USERNAME")
-				password = System.getenv("OSSRH_PASSWORD")
-			}
-		}
+	    maven {
+            name = "CentralPortal"
+            val releasesRepoUrl = "https://ossrh-staging-api.central.sonatype.com/service/local/staging/deploy/maven2/"
+            val snapshotsRepoUrl = "https://central.sonatype.com/repository/maven-snapshots/"
+            url = uri(
+                if (version.toString().endsWith("SNAPSHOT")) snapshotsRepoUrl else releasesRepoUrl
+            )
+            credentials {
+                username = System.getenv("CENTRAL_USERNAME")
+                password = System.getenv("CENTRAL_PASSWORD")
+            }
+        }
 	}
 }
 
