@@ -20,9 +20,6 @@ description = "PlantUML"
 java {
 	withSourcesJar()
 	withJavadocJar()
-	registerFeature("pdf") {
-		usingSourceSet(sourceSets["main"])
-	}
 }
 
 dependencies {
@@ -39,20 +36,14 @@ repositories {
 }
 
 sourceSets {
-	main {
-		java {
-			srcDirs("build/generated/sjpp")
-		}
-        resources {
-			srcDirs("../src/main/resources")
-        }
-	}
-}
-
-tasks.processResources {
-    from("../src/main/java") {
-        include("**/graphviz.dat", "**/*.svg", "**/*.png", "**/*.txt")
+  main {
+    java {
+      srcDirs("build/generated/sjpp")
     }
+    resources {
+      srcDir(rootProject.layout.projectDirectory.dir("src/main/resources"))
+    }
+  }
 }
 
 
@@ -69,7 +60,7 @@ tasks.withType<Jar>().configureEach {
 		attributes["Main-Class"] = "net.sourceforge.plantuml.Run"
 		attributes["Implementation-Version"] = archiveVersion
 		attributes["Build-Jdk-Spec"] = System.getProperty("java.specification.version")
-		from("../manifest.txt")
+		from(rootProject.layout.projectDirectory.file("manifest.txt"))
 	}
 
 	// source sets for java and resources are on "src", only put once into the jar
@@ -159,16 +150,18 @@ publishing {
 		}
 	}
 	repositories {
-		maven {
-			name = "OSSRH"
-			val releasesRepoUrl = "https://oss.sonatype.org/service/local/staging/deploy/maven2/"
-			val snapshotsRepoUrl = "https://oss.sonatype.org/content/repositories/snapshots/"
-			url = uri(if (version.toString().endsWith("SNAPSHOT")) snapshotsRepoUrl else releasesRepoUrl)
-			credentials {
-				username = System.getenv("OSSRH_USERNAME")
-				password = System.getenv("OSSRH_PASSWORD")
-			}
-		}
+	    maven {
+            name = "CentralPortal"
+            val releasesRepoUrl = "https://ossrh-staging-api.central.sonatype.com/service/local/staging/deploy/maven2/"
+            val snapshotsRepoUrl = "https://central.sonatype.com/repository/maven-snapshots/"
+            url = uri(
+                if (version.toString().endsWith("SNAPSHOT")) snapshotsRepoUrl else releasesRepoUrl
+            )
+            credentials {
+                username = System.getenv("CENTRAL_USERNAME")
+                password = System.getenv("CENTRAL_PASSWORD")
+            }
+        }
 	}
 }
 
@@ -190,18 +183,19 @@ application {
 }
 
 graalvmNative {
-  binaries.all { resources.autodetect() }
-	binaries.create("full") {
+	binaries.all {
+		resources.autodetect()
+		useFatJar.set(true)
+	}
+  	binaries.create("full") {
 		buildArgs(listOf("-Djava.awt.headless=false", "--enable-url-protocols=https"))
 		runtimeArgs(listOf("-Djava.awt.headless=false"))
 		imageName.set("plantuml-full")
 		mainClass.set(application.mainClass)
-		classpath(binaries.named("main").get().classpath)
 	}
 	binaries.create("headless") {
 		imageName.set("plantuml-headless")
 		mainClass.set(application.mainClass)
-		classpath(binaries.named("main").get().classpath)
 		runtimeArgs(listOf("-Djava.awt.headless=true"))
 		buildArgs(listOf("-Djava.awt.headless=true", "--enable-url-protocols=https"))
 	}
