@@ -53,7 +53,6 @@ import net.sourceforge.plantuml.file.FileGroup;
 import net.sourceforge.plantuml.klimt.color.ColorMapper;
 import net.sourceforge.plantuml.preproc.Defines;
 import net.sourceforge.plantuml.regex.Matcher2;
-import net.sourceforge.plantuml.regex.MyPattern;
 import net.sourceforge.plantuml.regex.Pattern2;
 import net.sourceforge.plantuml.security.SFile;
 import net.sourceforge.plantuml.stats.StatsUtils;
@@ -569,7 +568,7 @@ public class Option {
 	}
 
 	private void manageDefine(String s) {
-		final Pattern2 p = MyPattern.cmpile("^(\\$?\\w+)(?:=(.*))?$");
+		final Pattern2 p = Pattern2.cmpile("^(\\$?\\w+)(?:=(.*))?$");
 		final Matcher2 m = p.matcher(s);
 		if (m.find())
 			define(m.group(1), m.group(2));
@@ -577,7 +576,7 @@ public class Option {
 	}
 
 	private void managePragma(String s) {
-		final Pattern2 p = MyPattern.cmpile("^(\\w+)(?:=(.*))?$");
+		final Pattern2 p = Pattern2.cmpile("^(\\w+)(?:=(.*))?$");
 		final Matcher2 m = p.matcher(s);
 		if (m.find()) {
 			final String var = m.group(1);
@@ -589,7 +588,7 @@ public class Option {
 	}
 
 	private void manageSkinParam(String s) {
-		final Pattern2 p = MyPattern.cmpile("^(\\w+)(?:=(.*))?$");
+		final Pattern2 p = Pattern2.cmpile("^(\\w+)(?:=(.*))?$");
 		final Matcher2 m = p.matcher(s);
 		if (m.find()) {
 			final String var = m.group(1);
