@@ -36,11 +36,12 @@
 package net.sourceforge.plantuml.klimt.sprite;
 
 import java.awt.image.BufferedImage;
-import java.io.IOException;
 import java.io.InputStream;
 import java.util.Objects;
 
 import net.atmp.PixelImage;
+import net.sourceforge.plantuml.FileUtils;
+import net.sourceforge.plantuml.emoji.SvgNanoParser;
 import net.sourceforge.plantuml.klimt.AffineTransformType;
 import net.sourceforge.plantuml.klimt.color.ColorMapper;
 import net.sourceforge.plantuml.klimt.color.HColor;
@@ -84,16 +85,20 @@ public class SpriteImage implements Sprite {
 	}
 
 	public static Sprite fromInternal(String name) {
-		if (name.endsWith(".png"))
+		if (name.endsWith(".png") || name.endsWith(".svg"))
 			throw new IllegalArgumentException();
 
-		final InputStream is = getInternalSprite(name + ".png");
-		if (is == null)
+		try {
+			InputStream is;
+			is = getInternalSprite(name + ".svg");
+			if (is != null)
+				return new SvgNanoParser(FileUtils.readAllBytes(is));
+			is = getInternalSprite(name + ".png");
+			if (is != null)
+				return new SpriteImage(SImageIO.read(is));
 			return null;
 
-		try {
-			return new SpriteImage(SImageIO.read(is));
-		} catch (IOException e) {
+		} catch (Throwable e) {
 			Logme.error(e);
 			return null;
 		}
