@@ -77,7 +77,7 @@ import net.sourceforge.plantuml.style.Style;
 
 class DrawableSetInitializer {
 
-	private ComponentType defaultLineType;
+	// private ComponentType defaultLineType;
 	private final DrawableSet drawableSet;
 	private final boolean showTail;
 
@@ -89,7 +89,7 @@ class DrawableSetInitializer {
 
 	private ConstraintSet constraintSet;
 
-	public DrawableSetInitializer(Rose skin, ISkinParam skinParam, boolean showTail, /*double autonewpage,*/
+	public DrawableSetInitializer(Rose skin, ISkinParam skinParam, boolean showTail, /* double autonewpage, */
 			AtomicInteger counter) {
 		this.drawableSet = new DrawableSet(skin, skinParam, counter);
 		this.showTail = showTail;
@@ -97,21 +97,6 @@ class DrawableSetInitializer {
 
 	}
 
-	private boolean useContinueLineBecauseOfDelay() {
-		final String strategy = drawableSet.getSkinParam().getValue("lifelineStrategy");
-		if ("nosolid".equalsIgnoreCase(strategy))
-			return false;
-
-		if ("solid".equalsIgnoreCase(strategy))
-			return true;
-
-		for (Event ev : drawableSet.getAllEvents())
-			if (ev instanceof Delay)
-				return true;
-
-		return false;
-	}
-
 	private ParticipantRange getFullParticipantRange() {
 		return new ParticipantRange(0, drawableSet.getAllParticipants().size());
 	}
@@ -135,8 +120,8 @@ class DrawableSetInitializer {
 		if (freeY2 != null)
 			throw new IllegalStateException();
 
-		this.defaultLineType = useContinueLineBecauseOfDelay() ? ComponentType.CONTINUE_LINE
-				: ComponentType.PARTICIPANT_LINE;
+//		this.defaultLineType = useContinueLineBecauseOfDelay() ? ComponentType.CONTINUE_LINE
+//				: ComponentType.PARTICIPANT_LINE;
 
 		for (Participant p : drawableSet.getAllParticipants())
 			prepareParticipant(stringBounder, p);
@@ -152,7 +137,7 @@ class DrawableSetInitializer {
 			final LivingParticipantBox living = drawableSet.getLivingParticipantBox(p);
 			for (int i = 0; i < p.getInitialLife(); i++)
 				living.getLifeLine().addSegmentVariation(LifeSegmentVariation.LARGER,
-						freeY2.getFreeY(getFullParticipantRange()), p.getLiveSpecificBackColors(i));
+						freeY2.getFreeY(getFullParticipantRange()), p.getLiveSpecificBackColors(i), null);
 
 		}
 
@@ -510,7 +495,8 @@ class DrawableSetInitializer {
 				pos = message.getPosYstartLevel() + delta1;
 			}
 			final LifeLine line1 = drawableSet.getLivingParticipantBox(lifeEvent.getParticipant()).getLifeLine();
-			line1.addSegmentVariation(LifeSegmentVariation.LARGER, pos, lifeEvent.getSpecificColors());
+			line1.addSegmentVariation(LifeSegmentVariation.LARGER, pos, lifeEvent.getSpecificColors(),
+					message == null ? null : message.getStyleBuilder());
 		} else if (lifeEvent.getType() == LifeEventType.DESTROY || lifeEvent.getType() == LifeEventType.DEACTIVATE) {
 			double delta = 0;
 			if (OptionFlags.STRICT_SELFMESSAGE_POSITION && message != null && message.isSelfMessage())
@@ -522,7 +508,8 @@ class DrawableSetInitializer {
 			if (message != null)
 				pos2 = message.getPosYendLevel() - delta;
 
-			line.addSegmentVariation(LifeSegmentVariation.SMALLER, pos2, lifeEvent.getSpecificColors());
+			line.addSegmentVariation(LifeSegmentVariation.SMALLER, pos2, lifeEvent.getSpecificColors(),
+					message == null ? null : message.getStyleBuilder());
 		}
 
 		if (lifeEvent.getType() == LifeEventType.DESTROY) {
@@ -645,10 +632,10 @@ class DrawableSetInitializer {
 				participantDisplay);
 		final Component tail = drawableSet.getSkin().createComponentParticipant(p, tailType, null, skinParam,
 				participantDisplay);
-		final Style style = this.defaultLineType.getStyleSignature().withTOBECHANGED(p.getStereotype())
+		final Style style = ComponentType.PARTICIPANT_LINE.getStyleSignature().withTOBECHANGED(p.getStereotype())
 				.getMergedStyle(skinParam.getCurrentStyleBuilder());
-		final Component line = drawableSet.getSkin().createComponent(new Style[] { style }, this.defaultLineType, null,
-				drawableSet.getSkinParam(), participantDisplay);
+		final Component line = drawableSet.getSkin().createComponent(new Style[] { style },
+				ComponentType.PARTICIPANT_LINE, null, drawableSet.getSkinParam(), participantDisplay);
 		final Style styleDelay = ComponentType.DELAY_LINE.getStyleSignature().withTOBECHANGED(p.getStereotype())
 				.getMergedStyle(skinParam.getCurrentStyleBuilder());
 		final Component delayLine = drawableSet.getSkin().createComponent(new Style[] { styleDelay },
@@ -656,10 +643,11 @@ class DrawableSetInitializer {
 		final ParticipantBox box = new ParticipantBox(skinParam.getPragma(), p.getLocation(), head, line, tail,
 				delayLine, this.freeX, skinParam.maxAsciiMessageLength() > 0 ? 1 : 5, p);
 
-		final Component comp = drawableSet.getSkin().createComponent(
-				new Style[] { ComponentType.ALIVE_BOX_CLOSE_CLOSE.getStyleSignature()
-						.getMergedStyle(drawableSet.getSkinParam().getCurrentStyleBuilder()) },
-				ComponentType.ALIVE_BOX_CLOSE_CLOSE, null, drawableSet.getSkinParam(), participantDisplay);
+		final Style activationBoxStyle = ComponentType.ACTIVATION_BOX_CLOSE_CLOSE.getStyleSignature()
+				.getMergedStyle(drawableSet.getSkinParam().getCurrentStyleBuilder());
+
+		final Component comp = drawableSet.getSkin().createComponent(new Style[] { activationBoxStyle },
+				ComponentType.ACTIVATION_BOX_CLOSE_CLOSE, null, drawableSet.getSkinParam(), participantDisplay);
 
 		final LifeLine lifeLine = new LifeLine(box, comp.getPreferredWidth(stringBounder),
 				drawableSet.getSkinParam().shadowing(p.getStereotype()), participantDisplay);
