@@ -45,6 +45,7 @@ import java.util.regex.Pattern;
 
 import net.sourceforge.plantuml.klimt.color.HColor;
 import net.sourceforge.plantuml.klimt.color.HColorSet;
+import net.sourceforge.plantuml.klimt.color.HColors;
 import net.sourceforge.plantuml.klimt.color.NoSuchColorException;
 import net.sourceforge.plantuml.klimt.font.UFont;
 import net.sourceforge.plantuml.klimt.shape.TextBlock;
@@ -112,7 +113,7 @@ public class Stereotype implements CharSequence {
 		if (tmp == null)
 			return null;
 
-		return tmp.asTextBlock(getHtmlColor(), getHtmlColor(), decoration.spriteScale);
+		return tmp.asTextBlock(getHtmlColor(), null, decoration.spriteScale);
 	}
 
 	public boolean isWithOOSymbol() {
